@@ -3,7 +3,7 @@ from inspect import CO_VARARGS
 import types
 import re
 
-from .cross import PY2
+from .compat import PY2
 from .decorators import unwrap
 
 
@@ -85,8 +85,8 @@ STD_MODULES = set(ARGS)
 
 # Describe some funcy functions, mostly for r?curry()
 ARGS['funcy.seqs'] = {
-    'map': 'f*', 'imap': 'f*', 'ximap': 'f*',
-    'mapcat': 'f*', 'imapcat': 'f*',
+    'map': 'f*', 'lmap': 'f*', 'xmap': 'f*',
+    'mapcat': 'f*', 'lmapcat': 'f*',
 }
 ARGS['funcy.colls'] = {
     'merge_with': 'f*',
@@ -100,7 +100,7 @@ def get_spec(func, _cache={}):
     func = getattr(func, '__original__', None) or unwrap(func)
     try:
         return _cache[func]
-    except:
+    except (KeyError, TypeError):
         pass
 
     mod = func.__module__
